# ory-kratos-client
Documentation for all public and administrative Ory Kratos APIs. Public and administrative APIs
are exposed on different ports. Public APIs can face the public internet without any protection
while administrative APIs should never be exposed without prior authorization. To protect
the administative API port you should use something like Nginx, Ory Oathkeeper, or any other
technology capable of authorizing incoming requests.


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v0.6.1-alpha.1
- Package version: v0.6.1-alpha.1
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python >= 3.6

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/ory/sdk.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/ory/sdk.git`)

Then import the package:
```python
import ory_kratos_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import ory_kratos_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import ory_kratos_client
from pprint import pprint
from ory_kratos_client.api import admin_api
from ory_kratos_client.model.create_identity import CreateIdentity
from ory_kratos_client.model.create_recovery_link import CreateRecoveryLink
from ory_kratos_client.model.error_container import ErrorContainer
from ory_kratos_client.model.generic_error import GenericError
from ory_kratos_client.model.identity import Identity
from ory_kratos_client.model.inline_response200 import InlineResponse200
from ory_kratos_client.model.inline_response2001 import InlineResponse2001
from ory_kratos_client.model.inline_response503 import InlineResponse503
from ory_kratos_client.model.login_flow import LoginFlow
from ory_kratos_client.model.recovery_flow import RecoveryFlow
from ory_kratos_client.model.recovery_link import RecoveryLink
from ory_kratos_client.model.registration_flow import RegistrationFlow
from ory_kratos_client.model.settings_flow import SettingsFlow
from ory_kratos_client.model.update_identity import UpdateIdentity
from ory_kratos_client.model.verification_flow import VerificationFlow
# Defining the host is optional and defaults to https://demo.tenants.oryapis.com/api/kratos/public
# See configuration.py for a list of all supported configuration parameters.
configuration = ory_kratos_client.Configuration(
    host = "https://demo.tenants.oryapis.com/api/kratos/public"
)



# Enter a context with an instance of the API client
with ory_kratos_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = admin_api.AdminApi(api_client)
    create_identity = CreateIdentity(
        schema_id="schema_id_example",
        traits={},
    ) # CreateIdentity |  (optional)

    try:
        # Create an Identity
        api_response = api_instance.create_identity(create_identity=create_identity)
        pprint(api_response)
    except ory_kratos_client.ApiException as e:
        print("Exception when calling AdminApi->create_identity: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://demo.tenants.oryapis.com/api/kratos/public*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AdminApi* | [**create_identity**](docs/AdminApi.md#create_identity) | **POST** /identities | Create an Identity
*AdminApi* | [**create_recovery_link**](docs/AdminApi.md#create_recovery_link) | **POST** /recovery/link | Create a Recovery Link
*AdminApi* | [**delete_identity**](docs/AdminApi.md#delete_identity) | **DELETE** /identities/{id} | Delete an Identity
*AdminApi* | [**get_identity**](docs/AdminApi.md#get_identity) | **GET** /identities/{id} | Get an Identity
*AdminApi* | [**get_schema**](docs/AdminApi.md#get_schema) | **GET** /schemas/{id} | 
*AdminApi* | [**get_self_service_error**](docs/AdminApi.md#get_self_service_error) | **GET** /self-service/errors | Get User-Facing Self-Service Errors
*AdminApi* | [**get_self_service_login_flow**](docs/AdminApi.md#get_self_service_login_flow) | **GET** /self-service/login/flows | Get Login Flow
*AdminApi* | [**get_self_service_recovery_flow**](docs/AdminApi.md#get_self_service_recovery_flow) | **GET** /self-service/recovery/flows | Get information about a recovery flow
*AdminApi* | [**get_self_service_registration_flow**](docs/AdminApi.md#get_self_service_registration_flow) | **GET** /self-service/registration/flows | Get Registration Flow
*AdminApi* | [**get_self_service_settings_flow**](docs/AdminApi.md#get_self_service_settings_flow) | **GET** /self-service/settings/flows | Get Settings Flow
*AdminApi* | [**get_self_service_verification_flow**](docs/AdminApi.md#get_self_service_verification_flow) | **GET** /self-service/verification/flows | Get Verification Flow
*AdminApi* | [**get_version**](docs/AdminApi.md#get_version) | **GET** /version | Return Running Software Version.
*AdminApi* | [**is_alive**](docs/AdminApi.md#is_alive) | **GET** /health/alive | Check HTTP Server Status
*AdminApi* | [**is_ready**](docs/AdminApi.md#is_ready) | **GET** /health/ready | Check HTTP Server and Database Status
*AdminApi* | [**list_identities**](docs/AdminApi.md#list_identities) | **GET** /identities | List Identities
*AdminApi* | [**prometheus**](docs/AdminApi.md#prometheus) | **GET** /metrics/prometheus | Get snapshot metrics from the Hydra service. If you&#39;re using k8s, you can then add annotations to your deployment like so:
*AdminApi* | [**update_identity**](docs/AdminApi.md#update_identity) | **PUT** /identities/{id} | Update an Identity
*PublicApi* | [**get_schema**](docs/PublicApi.md#get_schema) | **GET** /schemas/{id} | 
*PublicApi* | [**get_self_service_error**](docs/PublicApi.md#get_self_service_error) | **GET** /self-service/errors | Get User-Facing Self-Service Errors
*PublicApi* | [**get_self_service_login_flow**](docs/PublicApi.md#get_self_service_login_flow) | **GET** /self-service/login/flows | Get Login Flow
*PublicApi* | [**get_self_service_recovery_flow**](docs/PublicApi.md#get_self_service_recovery_flow) | **GET** /self-service/recovery/flows | Get information about a recovery flow
*PublicApi* | [**get_self_service_registration_flow**](docs/PublicApi.md#get_self_service_registration_flow) | **GET** /self-service/registration/flows | Get Registration Flow
*PublicApi* | [**get_self_service_settings_flow**](docs/PublicApi.md#get_self_service_settings_flow) | **GET** /self-service/settings/flows | Get Settings Flow
*PublicApi* | [**get_self_service_verification_flow**](docs/PublicApi.md#get_self_service_verification_flow) | **GET** /self-service/verification/flows | Get Verification Flow
*PublicApi* | [**initialize_self_service_browser_logout_flow**](docs/PublicApi.md#initialize_self_service_browser_logout_flow) | **GET** /self-service/browser/flows/logout | Initialize Browser-Based Logout User Flow
*PublicApi* | [**initialize_self_service_login_via_api_flow**](docs/PublicApi.md#initialize_self_service_login_via_api_flow) | **GET** /self-service/login/api | Initialize Login Flow for API clients
*PublicApi* | [**initialize_self_service_login_via_browser_flow**](docs/PublicApi.md#initialize_self_service_login_via_browser_flow) | **GET** /self-service/login/browser | Initialize Login Flow for browsers
*PublicApi* | [**initialize_self_service_recovery_via_api_flow**](docs/PublicApi.md#initialize_self_service_recovery_via_api_flow) | **GET** /self-service/recovery/api | Initialize Recovery Flow for API Clients
*PublicApi* | [**initialize_self_service_recovery_via_browser_flow**](docs/PublicApi.md#initialize_self_service_recovery_via_browser_flow) | **GET** /self-service/recovery/browser | Initialize Recovery Flow for Browser Clients
*PublicApi* | [**initialize_self_service_registration_via_api_flow**](docs/PublicApi.md#initialize_self_service_registration_via_api_flow) | **GET** /self-service/registration/api | Initialize Registration Flow for API clients
*PublicApi* | [**initialize_self_service_registration_via_browser_flow**](docs/PublicApi.md#initialize_self_service_registration_via_browser_flow) | **GET** /self-service/registration/browser | Initialize Registration Flow for browsers
*PublicApi* | [**initialize_self_service_settings_via_api_flow**](docs/PublicApi.md#initialize_self_service_settings_via_api_flow) | **GET** /self-service/settings/api | Initialize Settings Flow for API Clients
*PublicApi* | [**initialize_self_service_settings_via_browser_flow**](docs/PublicApi.md#initialize_self_service_settings_via_browser_flow) | **GET** /self-service/settings/browser | Initialize Settings Flow for Browsers
*PublicApi* | [**initialize_self_service_verification_via_api_flow**](docs/PublicApi.md#initialize_self_service_verification_via_api_flow) | **GET** /self-service/verification/api | Initialize Verification Flow for API Clients
*PublicApi* | [**initialize_self_service_verification_via_browser_flow**](docs/PublicApi.md#initialize_self_service_verification_via_browser_flow) | **GET** /self-service/verification/browser | Initialize Verification Flow for Browser Clients
*PublicApi* | [**revoke_session**](docs/PublicApi.md#revoke_session) | **DELETE** /sessions | Initialize Logout Flow for API Clients - Revoke a Session
*PublicApi* | [**submit_self_service_login_flow**](docs/PublicApi.md#submit_self_service_login_flow) | **POST** /self-service/login | Submit a Login Flow
*PublicApi* | [**submit_self_service_recovery_flow**](docs/PublicApi.md#submit_self_service_recovery_flow) | **POST** /self-service/recovery | Complete Recovery Flow
*PublicApi* | [**submit_self_service_recovery_flow_with_link_method**](docs/PublicApi.md#submit_self_service_recovery_flow_with_link_method) | **POST** /self-service/recovery/methods/link | Complete Recovery Flow with Link Method
*PublicApi* | [**submit_self_service_registration_flow**](docs/PublicApi.md#submit_self_service_registration_flow) | **POST** /self-service/registration | Submit a Registration Flow
*PublicApi* | [**submit_self_service_settings_flow**](docs/PublicApi.md#submit_self_service_settings_flow) | **POST** /self-service/settings | Complete Settings Flow
*PublicApi* | [**submit_self_service_verification_flow**](docs/PublicApi.md#submit_self_service_verification_flow) | **POST** /self-service/verification/methods/link | Complete Verification Flow
*PublicApi* | [**whoami**](docs/PublicApi.md#whoami) | **GET** /sessions/whoami | Check Who the Current HTTP Session Belongs To


## Documentation For Models

 - [AuthenticateOKBody](docs/AuthenticateOKBody.md)
 - [ContainerChangeResponseItem](docs/ContainerChangeResponseItem.md)
 - [ContainerCreateCreatedBody](docs/ContainerCreateCreatedBody.md)
 - [ContainerTopOKBody](docs/ContainerTopOKBody.md)
 - [ContainerUpdateOKBody](docs/ContainerUpdateOKBody.md)
 - [ContainerWaitOKBody](docs/ContainerWaitOKBody.md)
 - [ContainerWaitOKBodyError](docs/ContainerWaitOKBodyError.md)
 - [CreateIdentity](docs/CreateIdentity.md)
 - [CreateRecoveryLink](docs/CreateRecoveryLink.md)
 - [ErrorContainer](docs/ErrorContainer.md)
 - [ErrorResponse](docs/ErrorResponse.md)
 - [GenericError](docs/GenericError.md)
 - [GenericErrorPayload](docs/GenericErrorPayload.md)
 - [GraphDriverData](docs/GraphDriverData.md)
 - [HealthNotReadyStatus](docs/HealthNotReadyStatus.md)
 - [HealthStatus](docs/HealthStatus.md)
 - [IdResponse](docs/IdResponse.md)
 - [Identity](docs/Identity.md)
 - [IdentityCredentials](docs/IdentityCredentials.md)
 - [ImageDeleteResponseItem](docs/ImageDeleteResponseItem.md)
 - [ImageSummary](docs/ImageSummary.md)
 - [InlineResponse200](docs/InlineResponse200.md)
 - [InlineResponse2001](docs/InlineResponse2001.md)
 - [InlineResponse503](docs/InlineResponse503.md)
 - [LoginFlow](docs/LoginFlow.md)
 - [LoginViaApiResponse](docs/LoginViaApiResponse.md)
 - [Meta](docs/Meta.md)
 - [Plugin](docs/Plugin.md)
 - [PluginConfig](docs/PluginConfig.md)
 - [PluginConfigArgs](docs/PluginConfigArgs.md)
 - [PluginConfigInterface](docs/PluginConfigInterface.md)
 - [PluginConfigLinux](docs/PluginConfigLinux.md)
 - [PluginConfigNetwork](docs/PluginConfigNetwork.md)
 - [PluginConfigRootfs](docs/PluginConfigRootfs.md)
 - [PluginConfigUser](docs/PluginConfigUser.md)
 - [PluginDevice](docs/PluginDevice.md)
 - [PluginEnv](docs/PluginEnv.md)
 - [PluginInterfaceType](docs/PluginInterfaceType.md)
 - [PluginMount](docs/PluginMount.md)
 - [PluginSettings](docs/PluginSettings.md)
 - [Port](docs/Port.md)
 - [RecoveryAddress](docs/RecoveryAddress.md)
 - [RecoveryFlow](docs/RecoveryFlow.md)
 - [RecoveryLink](docs/RecoveryLink.md)
 - [RegistrationFlow](docs/RegistrationFlow.md)
 - [RegistrationViaApiResponse](docs/RegistrationViaApiResponse.md)
 - [RevokeSession](docs/RevokeSession.md)
 - [ServiceUpdateResponse](docs/ServiceUpdateResponse.md)
 - [Session](docs/Session.md)
 - [SettingsFlow](docs/SettingsFlow.md)
 - [SettingsProfileFormConfig](docs/SettingsProfileFormConfig.md)
 - [SettingsViaApiResponse](docs/SettingsViaApiResponse.md)
 - [SubmitSelfServiceBrowserSettingsOIDCFlowPayload](docs/SubmitSelfServiceBrowserSettingsOIDCFlowPayload.md)
 - [SubmitSelfServiceLoginFlow](docs/SubmitSelfServiceLoginFlow.md)
 - [SubmitSelfServiceLoginFlowWithPasswordMethod](docs/SubmitSelfServiceLoginFlowWithPasswordMethod.md)
 - [SubmitSelfServiceRecoveryFlowWithLinkMethod](docs/SubmitSelfServiceRecoveryFlowWithLinkMethod.md)
 - [SubmitSelfServiceRegistrationFlow](docs/SubmitSelfServiceRegistrationFlow.md)
 - [SubmitSelfServiceRegistrationFlowWithPasswordMethod](docs/SubmitSelfServiceRegistrationFlowWithPasswordMethod.md)
 - [SubmitSelfServiceSettingsFlow](docs/SubmitSelfServiceSettingsFlow.md)
 - [SubmitSelfServiceSettingsFlowWithPasswordMethod](docs/SubmitSelfServiceSettingsFlowWithPasswordMethod.md)
 - [SubmitSelfServiceSettingsFlowWithProfileMethod](docs/SubmitSelfServiceSettingsFlowWithProfileMethod.md)
 - [SubmitSelfServiceVerificationFlowWithLinkMethod](docs/SubmitSelfServiceVerificationFlowWithLinkMethod.md)
 - [UiContainer](docs/UiContainer.md)
 - [UiNode](docs/UiNode.md)
 - [UiNodeAnchorAttributes](docs/UiNodeAnchorAttributes.md)
 - [UiNodeAttributes](docs/UiNodeAttributes.md)
 - [UiNodeImageAttributes](docs/UiNodeImageAttributes.md)
 - [UiNodeInputAttributes](docs/UiNodeInputAttributes.md)
 - [UiNodeInputAttributesValue](docs/UiNodeInputAttributesValue.md)
 - [UiNodeTextAttributes](docs/UiNodeTextAttributes.md)
 - [UiNodes](docs/UiNodes.md)
 - [UiText](docs/UiText.md)
 - [UiTexts](docs/UiTexts.md)
 - [UpdateIdentity](docs/UpdateIdentity.md)
 - [VerifiableAddress](docs/VerifiableAddress.md)
 - [VerificationFlow](docs/VerificationFlow.md)
 - [Version](docs/Version.md)
 - [Volume](docs/Volume.md)
 - [VolumeUsageData](docs/VolumeUsageData.md)


## Documentation For Authorization


## sessionCookie

- **Type**: API key
- **API key parameter name**: ory_kratos_session
- **Location**: 


## sessionToken

- **Type**: API key
- **API key parameter name**: X-Session-Token
- **Location**: HTTP header


## Author

hi@ory.sh


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in ory_kratos_client.apis and ory_kratos_client.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from ory_kratos_client.api.default_api import DefaultApi`
- `from ory_kratos_client.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import ory_kratos_client
from ory_kratos_client.apis import *
from ory_kratos_client.models import *
```

